Index: dm/DMUtil.h |
diff --git a/dm/DMUtil.h b/dm/DMUtil.h |
index e808ca0f8f4cc730cc72ad3655e954b9e583f1bd..c95f93346a2de425faa9a757b342b52d33707d5e 100644 |
--- a/dm/DMUtil.h |
+++ b/dm/DMUtil.h |
@@ -1,6 +1,7 @@ |
#ifndef DMUtil_DEFINED |
#define DMUtil_DEFINED |
+#include "SkBitmap.h" |
#include "SkString.h" |
#include "gm_expectations.h" |
@@ -14,9 +15,8 @@ SkString underJoin(const char* a, const char* b); |
// png("a") -> "a.png" |
SkString png(SkString s); |
-// Roughly, expectations.match(digest), but only does it if we're not ignoring the result. |
-bool meetsExpectations(const skiagm::Expectations& expectations, |
- const skiagm::GmResultDigest& digest); |
+// Roughly, expectations.match(GmResultDigest(bitmap)), but calculates the digest lazily. |
+bool meetsExpectations(const skiagm::Expectations& expectations, const SkBitmap bitmap); |
} // namespace DM |